Welcome to gograph
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

``` sh
pip install gograph

conda install gograph
```

## How to use

The lib provides a `Graph` class that you can use create and analyse
graphs!

``` python
g = Graph(vertices=['u', 'v', 'z'], edges=['uv', 'uz', 'zz'])
g.n_vertices()
```

    3
